@@ -1,8 +1,8 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
-"""this module contains a set of functions to handle python protocols for nodes
+"""This module contains a set of functions to handle python protocols for nodes
 where it makes sense.
 """
 
@@ -11,10 +11,10 @@ from __future__ import annotations
 import collections
 import itertools
 import operator as operator_mod
-from collections.abc import Callable, Generator
-from typing import Any
+from collections.abc import Callable, Generator, Iterator, Sequence
+from typing import TYPE_CHECKING, Any, TypeVar
 
-from astroid import arguments, bases, decorators, helpers, nodes, util
+from astroid import bases, decorators, nodes, util
 from astroid.const import Context
 from astroid.context import InferenceContext, copy_context
 from astroid.exceptions import (
@@ -25,50 +25,17 @@ from astroid.exceptions import (
     NoDefault,
 )
 from astroid.nodes import node_classes
-from astroid.typing import ConstFactoryResult
-
-raw_building = util.lazy_import("raw_building")
-objects = util.lazy_import("objects")
-
-
-def _reflected_name(name):
-    return "__r" + name[2:]
-
-
-def _augmented_name(name):
-    return "__i" + name[2:]
+from astroid.typing import (
+    ConstFactoryResult,
+    InferenceResult,
+    SuccessfulInferenceResult,
+)
 
+if TYPE_CHECKING:
+    _TupleListNodeT = TypeVar("_TupleListNodeT", nodes.Tuple, nodes.List)
 
 _CONTEXTLIB_MGR = "contextlib.contextmanager"
-BIN_OP_METHOD = {
-    "+": "__add__",
-    "-": "__sub__",
-    "/": "__truediv__",
-    "//": "__floordiv__",
-    "*": "__mul__",
-    "**": "__pow__",
-    "%": "__mod__",
-    "&": "__and__",
-    "|": "__or__",
-    "^": "__xor__",
-    "<<": "__lshift__",
-    ">>": "__rshift__",
-    "@": "__matmul__",
-}
 
-REFLECTED_BIN_OP_METHOD = {
-    key: _reflected_name(value) for (key, value) in BIN_OP_METHOD.items()
-}
-AUGMENTED_OP_METHOD = {
-    key + "=": _augmented_name(value) for (key, value) in BIN_OP_METHOD.items()
-}
-
-UNARY_OP_METHOD = {
-    "+": "__pos__",
-    "-": "__neg__",
-    "~": "__invert__",
-    "not": None,  # XXX not '__nonzero__'
-}
 _UNARY_OPERATORS: dict[str, Callable[[Any], Any]] = {
     "+": operator_mod.pos,
     "-": operator_mod.neg,
@@ -90,11 +57,25 @@ def _infer_unary_op(obj: Any, op: str) -> ConstFactoryResult:
     return nodes.const_factory(value)
 
 
-nodes.Tuple.infer_unary_op = lambda self, op: _infer_unary_op(tuple(self.elts), op)
-nodes.List.infer_unary_op = lambda self, op: _infer_unary_op(self.elts, op)
-nodes.Set.infer_unary_op = lambda self, op: _infer_unary_op(set(self.elts), op)
-nodes.Const.infer_unary_op = lambda self, op: _infer_unary_op(self.value, op)
-nodes.Dict.infer_unary_op = lambda self, op: _infer_unary_op(dict(self.items), op)
+def tuple_infer_unary_op(self, op):
+    return _infer_unary_op(tuple(self.elts), op)
+
+
+def list_infer_unary_op(self, op):
+    return _infer_unary_op(self.elts, op)
+
+
+def set_infer_unary_op(self, op):
+    return _infer_unary_op(set(self.elts), op)
+
+
+def const_infer_unary_op(self, op):
+    return _infer_unary_op(self.value, op)
+
+
+def dict_infer_unary_op(self, op):
+    return _infer_unary_op(dict(self.items), op)
+
 
 # Binary operations
 
@@ -118,12 +99,18 @@ for _KEY, _IMPL in list(BIN_OP_IMPL.items()):
 
 
 @decorators.yes_if_nothing_inferred
-def const_infer_binary_op(self, opnode, operator, other, context, _):
+def const_infer_binary_op(
+    self: nodes.Const,
+    opnode: nodes.AugAssign | nodes.BinOp,
+    operator: str,
+    other: InferenceResult,
+    context: InferenceContext,
+    _: SuccessfulInferenceResult,
+) -> Generator[ConstFactoryResult | util.UninferableBase]:
     not_implemented = nodes.Const(NotImplemented)
     if isinstance(other, nodes.Const):
         if (
             operator == "**"
-            and isinstance(self, nodes.Const)
             and isinstance(self.value, (int, float))
             and isinstance(other.value, (int, float))
             and (self.value > 1e5 or other.value > 1e5)
@@ -148,27 +135,34 @@ def const_infer_binary_op(self, opnode, operator, other, context, _):
         yield not_implemented
 
 
-nodes.Const.infer_binary_op = const_infer_binary_op
-
-
-def _multiply_seq_by_int(self, opnode, other, context):
+def _multiply_seq_by_int(
+    self: _TupleListNodeT,
+    opnode: nodes.AugAssign | nodes.BinOp,
+    value: int,
+    context: InferenceContext,
+) -> _TupleListNodeT:
     node = self.__class__(parent=opnode)
+    if value > 1e8:
+        node.elts = [util.Uninferable]
+        return node
     filtered_elts = (
-        helpers.safe_infer(elt, context) or util.Uninferable
+        util.safe_infer(elt, context) or util.Uninferable
         for elt in self.elts
-        if elt is not util.Uninferable
+        if not isinstance(elt, util.UninferableBase)
     )
-    node.elts = list(filtered_elts) * other.value
+    node.elts = list(filtered_elts) * value
     return node
 
 
-def _filter_uninferable_nodes(elts, context):
+def _filter_uninferable_nodes(
+    elts: Sequence[InferenceResult], context: InferenceContext
+) -> Iterator[SuccessfulInferenceResult]:
     for elt in elts:
-        if elt is util.Uninferable:
+        if isinstance(elt, util.UninferableBase):
             yield nodes.Unknown()
         else:
             for inferred in elt.infer(context):
-                if inferred is not util.Uninferable:
+                if not isinstance(inferred, util.UninferableBase):
                     yield inferred
                 else:
                     yield nodes.Unknown()
@@ -176,19 +170,21 @@ def _filter_uninferable_nodes(elts, context):
 
 @decorators.yes_if_nothing_inferred
 def tl_infer_binary_op(
-    self,
-    opnode: nodes.BinOp,
+    self: _TupleListNodeT,
+    opnode: nodes.AugAssign | nodes.BinOp,
     operator: str,
-    other: nodes.NodeNG,
+    other: InferenceResult,
     context: InferenceContext,
-    method: nodes.FunctionDef,
-) -> Generator[nodes.NodeNG | type[util.Uninferable], None, None]:
+    method: SuccessfulInferenceResult,
+) -> Generator[_TupleListNodeT | nodes.Const | util.UninferableBase]:
     """Infer a binary operation on a tuple or list.
 
     The instance on which the binary operation is performed is a tuple
     or list. This refers to the left-hand side of the operation, so:
     'tuple() + 1' or '[] + A()'
     """
+    from astroid import helpers  # pylint: disable=import-outside-toplevel
+
     # For tuples and list the boundnode is no longer the tuple or list instance
     context.boundnode = None
     not_implemented = nodes.Const(NotImplemented)
@@ -205,34 +201,36 @@ def tl_infer_binary_op(
         if not isinstance(other.value, int):
             yield not_implemented
             return
-        yield _multiply_seq_by_int(self, opnode, other, context)
+        yield _multiply_seq_by_int(self, opnode, other.value, context)
     elif isinstance(other, bases.Instance) and operator == "*":
         # Verify if the instance supports __index__.
         as_index = helpers.class_instance_as_index(other)
         if not as_index:
             yield util.Uninferable
+        elif not isinstance(as_index.value, int):  # pragma: no cover
+            # already checked by class_instance_as_index() but faster than casting
+            raise AssertionError("Please open a bug report.")
         else:
-            yield _multiply_seq_by_int(self, opnode, as_index, context)
+            yield _multiply_seq_by_int(self, opnode, as_index.value, context)
     else:
         yield not_implemented
 
 
-nodes.Tuple.infer_binary_op = tl_infer_binary_op
-nodes.List.infer_binary_op = tl_infer_binary_op
-
-
 @decorators.yes_if_nothing_inferred
-def instance_class_infer_binary_op(self, opnode, operator, other, context, method):
+def instance_class_infer_binary_op(
+    self: nodes.ClassDef,
+    opnode: nodes.AugAssign | nodes.BinOp,
+    operator: str,
+    other: InferenceResult,
+    context: InferenceContext,
+    method: SuccessfulInferenceResult,
+) -> Generator[InferenceResult]:
     return method.infer_call_result(self, context)
 
 
-bases.Instance.infer_binary_op = instance_class_infer_binary_op
-nodes.ClassDef.infer_binary_op = instance_class_infer_binary_op
-
-
 # assignment ##################################################################
-
-"""the assigned_stmts method is responsible to return the assigned statement
+# pylint: disable-next=pointless-string-statement
+"""The assigned_stmts method is responsible to return the assigned statement
 (e.g. not inferred) according to the assignment type.
 
 The `assign_path` argument is used to record the lhs path of the original node.
@@ -245,11 +243,11 @@ to any intermediary inference necessary.
 
 
 def _resolve_looppart(parts, assign_path, context):
-    """recursive function to resolve multiple assignments on loops"""
+    """Recursive function to resolve multiple assignments on loops."""
     assign_path = assign_path[:]
     index = assign_path.pop(0)
     for part in parts:
-        if part is util.Uninferable:
+        if isinstance(part, util.UninferableBase):
             continue
         if not hasattr(part, "itered"):
             continue
@@ -272,7 +270,7 @@ def _resolve_looppart(parts, assign_path, context):
                 # we achieved to resolved the assignment path,
                 # don't infer the last part
                 yield assigned
-            elif assigned is util.Uninferable:
+            elif isinstance(assigned, util.UninferableBase):
                 break
             else:
                 # we are not yet on the last part of the path
@@ -294,18 +292,24 @@ def for_assigned_stmts(
 ) -> Any:
     if isinstance(self, nodes.AsyncFor) or getattr(self, "is_async", False):
         # Skip inferring of async code for now
-        return dict(node=self, unknown=node, assign_path=assign_path, context=context)
+        return {
+            "node": self,
+            "unknown": node,
+            "assign_path": assign_path,
+            "context": context,
+        }
     if assign_path is None:
         for lst in self.iter.infer(context):
             if isinstance(lst, (nodes.Tuple, nodes.List)):
                 yield from lst.elts
     else:
         yield from _resolve_looppart(self.iter.infer(context), assign_path, context)
-    return dict(node=self, unknown=node, assign_path=assign_path, context=context)
-
-
-nodes.For.assigned_stmts = for_assigned_stmts
-nodes.Comprehension.assigned_stmts = for_assigned_stmts
+    return {
+        "node": self,
+        "unknown": node,
+        "assign_path": assign_path,
+        "context": context,
+    }
 
 
 def sequence_assigned_stmts(
@@ -332,10 +336,6 @@ def sequence_assigned_stmts(
     )
 
 
-nodes.Tuple.assigned_stmts = sequence_assigned_stmts
-nodes.List.assigned_stmts = sequence_assigned_stmts
-
-
 def assend_assigned_stmts(
     self: nodes.AssignName | nodes.AssignAttr,
     node: node_classes.AssignedStmtsPossibleNode = None,
@@ -345,21 +345,22 @@ def assend_assigned_stmts(
     return self.parent.assigned_stmts(node=self, context=context)
 
 
-nodes.AssignName.assigned_stmts = assend_assigned_stmts
-nodes.AssignAttr.assigned_stmts = assend_assigned_stmts
-
-
-def _arguments_infer_argname(self, name, context):
+def _arguments_infer_argname(
+    self, name: str | None, context: InferenceContext
+) -> Generator[InferenceResult]:
     # arguments information may be missing, in which case we can't do anything
     # more
-    if not (self.arguments or self.vararg or self.kwarg):
+    from astroid import arguments  # pylint: disable=import-outside-toplevel
+
+    if not self.arguments:
         yield util.Uninferable
         return
 
+    args = [arg for arg in self.arguments if arg.name not in [self.vararg, self.kwarg]]
     functype = self.parent.type
     # first argument of instance/class method
     if (
-        self.arguments
+        args
         and getattr(self.arguments[0], "name", None) == name
         and functype != "staticmethod"
     ):
@@ -388,7 +389,7 @@ def _arguments_infer_argname(self, name, context):
     if name == self.vararg:
         vararg = nodes.const_factory(())
         vararg.parent = self
-        if not self.arguments and self.parent.name == "__init__":
+        if not args and self.parent.name == "__init__":
             cls = self.parent.parent.scope()
             vararg.elts = [cls.instantiate_class()]
         yield vararg
@@ -414,11 +415,13 @@ def arguments_assigned_stmts(
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
 ) -> Any:
+    from astroid import arguments  # pylint: disable=import-outside-toplevel
+
     try:
         node_name = node.name  # type: ignore[union-attr]
     except AttributeError:
         # Added to handle edge cases where node.name is not defined.
-        # https://github.com/PyCQA/astroid/pull/1644#discussion_r901545816
+        # https://github.com/pylint-dev/astroid/pull/1644#discussion_r901545816
         node_name = None  # pragma: no cover
 
     if context and context.callcontext:
@@ -427,7 +430,7 @@ def arguments_assigned_stmts(
             callee = callee._proxied
     else:
         return _arguments_infer_argname(self, node_name, context)
-    if node and getattr(callee, "name", None) == node.frame(future=True).name:
+    if node and getattr(callee, "name", None) == node.frame().name:
         # reset call context/name
         callcontext = context.callcontext
         context = copy_context(context)
@@ -437,12 +440,9 @@ def arguments_assigned_stmts(
     return _arguments_infer_argname(self, node_name, context)
 
 
-nodes.Arguments.assigned_stmts = arguments_assigned_stmts
-
-
 @decorators.raise_if_nothing_inferred
 def assign_assigned_stmts(
-    self: nodes.AugAssign | nodes.Assign | nodes.AnnAssign,
+    self: nodes.AugAssign | nodes.Assign | nodes.AnnAssign | nodes.TypeAlias,
     node: node_classes.AssignedStmtsPossibleNode = None,
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
@@ -454,7 +454,12 @@ def assign_assigned_stmts(
         self.value.infer(context), assign_path, context
     )
 
-    return dict(node=self, unknown=node, assign_path=assign_path, context=context)
+    return {
+        "node": self,
+        "unknown": node,
+        "assign_path": assign_path,
+        "context": context,
+    }
 
 
 def assign_annassigned_stmts(
@@ -470,13 +475,8 @@ def assign_annassigned_stmts(
             yield inferred
 
 
-nodes.Assign.assigned_stmts = assign_assigned_stmts
-nodes.AnnAssign.assigned_stmts = assign_annassigned_stmts
-nodes.AugAssign.assigned_stmts = assign_assigned_stmts
-
-
 def _resolve_assignment_parts(parts, assign_path, context):
-    """recursive function to resolve multiple assignments"""
+    """Recursive function to resolve multiple assignments."""
     assign_path = assign_path[:]
     index = assign_path.pop(0)
     for part in parts:
@@ -502,7 +502,7 @@ def _resolve_assignment_parts(parts, assign_path, context):
             # we achieved to resolved the assignment path, don't infer the
             # last part
             yield assigned
-        elif assigned is util.Uninferable:
+        elif isinstance(assigned, util.UninferableBase):
             return
         else:
             # we are not yet on the last part of the path search on each
@@ -522,15 +522,19 @@ def excepthandler_assigned_stmts(
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
 ) -> Any:
+    from astroid import objects  # pylint: disable=import-outside-toplevel
+
     for assigned in node_classes.unpack_infer(self.type):
         if isinstance(assigned, nodes.ClassDef):
             assigned = objects.ExceptionInstance(assigned)
 
         yield assigned
-    return dict(node=self, unknown=node, assign_path=assign_path, context=context)
-
-
-nodes.ExceptHandler.assigned_stmts = excepthandler_assigned_stmts
+    return {
+        "node": self,
+        "unknown": node,
+        "assign_path": assign_path,
+        "context": context,
+    }
 
 
 def _infer_context_manager(self, mgr, context):
@@ -643,10 +647,12 @@ def with_assigned_stmts(
                         context=context,
                     ) from exc
             yield obj
-    return dict(node=self, unknown=node, assign_path=assign_path, context=context)
-
-
-nodes.With.assigned_stmts = with_assigned_stmts
+    return {
+        "node": self,
+        "unknown": node,
+        "assign_path": assign_path,
+        "context": context,
+    }
 
 
 @decorators.raise_if_nothing_inferred
@@ -656,7 +662,7 @@ def named_expr_assigned_stmts(
     context: InferenceContext | None = None,
     assign_path: list[int] | None = None,
 ) -> Any:
-    """Infer names and other nodes from an assignment expression"""
+    """Infer names and other nodes from an assignment expression."""
     if self.target == node:
         yield from self.value.infer(context=context)
     else:
@@ -668,11 +674,8 @@ def named_expr_assigned_stmts(
         )
 
 
-nodes.NamedExpr.assigned_stmts = named_expr_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
-def starred_assigned_stmts(
+def starred_assigned_stmts(  # noqa: C901
     self: nodes.Starred,
     node: node_classes.AssignedStmtsPossibleNode = None,
     context: InferenceContext | None = None,
@@ -687,6 +690,7 @@ def starred_assigned_stmts(
             A list of indices, where each index specifies what item to fetch from
             the inference results.
     """
+
     # pylint: disable=too-many-locals,too-many-statements
     def _determine_starred_iteration_lookups(
         starred: nodes.Starred, target: nodes.Tuple, lookups: list[tuple[int, int]]
@@ -704,7 +708,7 @@ def starred_assigned_stmts(
                 lookups.append((index, len(element.itered())))
                 _determine_starred_iteration_lookups(starred, element, lookups)
 
-    stmt = self.statement(future=True)
+    stmt = self.statement()
     if not isinstance(stmt, (nodes.Assign, nodes.For)):
         raise InferenceError(
             "Statement {stmt!r} enclosing {node!r} must be an Assign or For node.",
@@ -738,7 +742,7 @@ def starred_assigned_stmts(
         except (InferenceError, StopIteration):
             yield util.Uninferable
             return
-        if rhs is util.Uninferable or not hasattr(rhs, "itered"):
+        if isinstance(rhs, util.UninferableBase) or not hasattr(rhs, "itered"):
             yield util.Uninferable
             return
 
@@ -786,7 +790,7 @@ def starred_assigned_stmts(
         except (InferenceError, StopIteration):
             yield util.Uninferable
             return
-        if inferred_iterable is util.Uninferable or not hasattr(
+        if isinstance(inferred_iterable, util.UninferableBase) or not hasattr(
             inferred_iterable, "itered"
         ):
             yield util.Uninferable
@@ -823,7 +827,6 @@ def starred_assigned_stmts(
         last_lookup = lookup_slice
 
         for element in itered:
-
             # We probably want to infer the potential values *for each* element in an
             # iterable, but we can't infer a list of all values, when only a list of
             # step values are expected:
@@ -868,16 +871,13 @@ def starred_assigned_stmts(
         yield util.Uninferable
 
 
-nodes.Starred.assigned_stmts = starred_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def match_mapping_assigned_stmts(
     self: nodes.MatchMapping,
     node: nodes.AssignName,
     context: InferenceContext | None = None,
     assign_path: None = None,
-) -> Generator[nodes.NodeNG, None, None]:
+) -> Generator[nodes.NodeNG]:
     """Return empty generator (return -> raises StopIteration) so inferred value
     is Uninferable.
     """
@@ -885,16 +885,13 @@ def match_mapping_assigned_stmts(
     yield
 
 
-nodes.MatchMapping.assigned_stmts = match_mapping_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def match_star_assigned_stmts(
     self: nodes.MatchStar,
     node: nodes.AssignName,
     context: InferenceContext | None = None,
     assign_path: None = None,
-) -> Generator[nodes.NodeNG, None, None]:
+) -> Generator[nodes.NodeNG]:
     """Return empty generator (return -> raises StopIteration) so inferred value
     is Uninferable.
     """
@@ -902,16 +899,13 @@ def match_star_assigned_stmts(
     yield
 
 
-nodes.MatchStar.assigned_stmts = match_star_assigned_stmts
-
-
 @decorators.yes_if_nothing_inferred
 def match_as_assigned_stmts(
     self: nodes.MatchAs,
     node: nodes.AssignName,
     context: InferenceContext | None = None,
     assign_path: None = None,
-) -> Generator[nodes.NodeNG, None, None]:
+) -> Generator[nodes.NodeNG]:
     """Infer MatchAs as the Match subject if it's the only MatchCase pattern
     else raise StopIteration to yield Uninferable.
     """
@@ -923,4 +917,14 @@ def match_as_assigned_stmts(
         yield self.parent.parent.subject
 
 
-nodes.MatchAs.assigned_stmts = match_as_assigned_stmts
+@decorators.yes_if_nothing_inferred
+def generic_type_assigned_stmts(
+    self: nodes.TypeVar | nodes.TypeVarTuple | nodes.ParamSpec,
+    node: nodes.AssignName,
+    context: InferenceContext | None = None,
+    assign_path: None = None,
+) -> Generator[nodes.NodeNG]:
+    """Hack. Return any Node so inference doesn't fail
+    when evaluating __class_getitem__. Revert if it's causing issues.
+    """
+    yield nodes.Const(None)
